@@ -190,3 +190,6 @@ class NDVariable:
 
     def __rsub__(self, other):
         return other - self.value
+
+    def __str__(self):
+        return f"{self.name} {self.vals} {self.unit}"
